#
# spec file for package gtksourceview2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   gtksourceview
Name:           gtksourceview2
Version:        2.10.5
Release:        23.2
Summary:        GTK+ Source Editing Widget
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            http://www.gnome.org/
Source:         http://download.gnome.org/sources/gtksourceview/2.10/%{_name}-%{version}.tar.bz2
# PATCH-FEATURE-OPENSUSE gtksourceview-2.10.5-rpmspec_highlight.patch bgo#676261 lazy.kent@opensuse.org -- add SUSE-specific highlights for rpm spec
Patch0:         gtksourceview-2.10.5-rpmspec_highlight.patch
# PATCH-FIX-UPSTREAM port-to-c99.patch -- Fix build with gcc14
Patch1:         port-to-c99.patch

BuildRequires:  fdupes
BuildRequires:  gtk2-devel
BuildRequires:  intltool
BuildRequires:  libxml2-devel

%description
GtkSourceView is a text widget that extends GtkTextView, the standard
GTK+ text widget.

It improves GtkTextView by implementing syntax highlighting and other
features typical of a source editor.

%package -n libgtksourceview-2_0-0
Summary:        GTK+ Source Editing Widget
Group:          System/GUI/GNOME
# This is needed to make lang package installable.
Provides:       %{name} = %{version}

%description -n libgtksourceview-2_0-0
GtkSourceView is a text widget that extends GtkTextView, the standard
GTK+ text widget.

It improves GtkTextView by implementing syntax highlighting and other
features typical of a source editor.

%package devel
Summary:        GTK+ Source Editing Widget
Group:          System/GUI/GNOME
Requires:       gtk2-devel
Requires:       libgtksourceview-2_0-0 = %{version}
Requires:       libxml2-devel
Obsoletes:      gtksourceview-doc <= 2.5.4
Provides:       gtksourceview-doc = 2.5.4
Obsoletes:      glade3-catalog-gtksourceview

%description devel
GtkSourceView is a text widget that extends GtkTextView, the standard
GTK+ text widget.

It improves GtkTextView by implementing syntax highlighting and other
features typical of a source editor.

%lang_package

%prep
%autosetup -n %{_name}-%{version} -p1

%build
%configure \
        --disable-gtk-doc \
	--with-pic \
	--disable-static
make %{?_smp_mflags} V=1

%install
%make_install
%find_lang %{_name}-2.0
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}

%post -n libgtksourceview-2_0-0 -p /sbin/ldconfig
%postun -n libgtksourceview-2_0-0 -p /sbin/ldconfig

%files -n libgtksourceview-2_0-0
%license COPYING
%doc AUTHORS ChangeLog MAINTAINERS NEWS README
%{_libdir}/libgtksourceview-2.0.so.*
%{_datadir}/gtksourceview-2.0/

%files devel
%{_includedir}/gtksourceview-2.0/
%{_libdir}/libgtksourceview-2.0.so
%{_libdir}/pkgconfig/gtksourceview-2.0.pc
%{_datadir}/gtk-doc/

%files lang -f %{_name}-2.0.lang

%changelog
* Wed Jul 10 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Add port-to-c99.patch: Fix build with gcc14.
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Own /usr/share/gtk-doc: glib no longer uses gtk-doc and as a
  consequence cannot be held responsible to deliver that basic
  directory structure.
* Tue Nov 28 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup instead of %%setup/%%patch.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
- Fix Source URL.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed May 31 2017 zaitor@opensuse.org
- Drop optional libgladeui-1_0-devel BuildRequires and stop passing
  - -enable-glade-catalog to configure, no longer build glade
  support.
- Following the above, drop glade3-catalog-gtksourceview subpackage
  and obsolete it from devel package.
* Mon Jun 29 2015 olaf@aepfle.de
- Make glade catalog optional (based on bcond_without) because
  SLE12 misses the devel package.
* Thu May 17 2012 lazy.kent@opensuse.org
- Add gtksourceview-2.10.5-rpmspec_highlight.patch: add
  openSUSE-specific highlights for rpm spec (bgo#676261).
* Sat Jan 21 2012 zaitor@opensuse.org
- Fixed error in sourceurl.
* Wed Mar 16 2011 fcrozat@novell.com
- Rename package to gtksourceview2 to track gtk2 version.
- Remove Obsoletes for gtksourceview2 from libgtksourceview-2_0-0:
  this is not needed anymore with the renaming. However, the
  Provides is still needed for the lang package.
* Tue Oct  5 2010 vuntz@opensuse.org
- Split glade3 catalog in a glade3-catalog-gtksourceview
  subpackage. Part of bnc#637694.
- Update summaries and descriptions.
* Tue Sep 28 2010 vuntz@opensuse.org
- Update to version 2.10.5:
  + Updated translations.
* Tue Aug 31 2010 aj@suse.de
- Recommend instead of require lang package since it's not mandatory.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 2.10.4:
  + Misc bugfixes
  + Updated translations
- Changes from version 2.10.3:
  + Misc bugfixes
  + Updated translations
* Thu May  6 2010 dimstar@opensuse.org
- Update to version 2.10.1:
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations.
* Sun Mar 28 2010 vuntz@opensuse.org
- Update to version 2.10.0:
  + Misc bugfixes
  + Updated translations.
* Tue Mar 23 2010 vuntz@opensuse.org
- Pass --enable-glade-catalog to configure and add
  libgladeui-1_0-devel BuildRequires to get the glade3 catalog.
* Wed Mar 17 2010 dimstar@opensuse.org
- Update to version 2.9.9:
  + Distribute a catalog for glade3
  + Misc bugfixes
  + Updated translations.
* Wed Mar  3 2010 dimstar@opensuse.org
- Update to version 2.9.8:
  + Bugfixes in the "words" completion provider
  + Misc bugfixes
  + Updated translations
* Mon Feb 22 2010 vuntz@opensuse.org
- Update to version 2.9.7:
  + Remove a leftover in the UndoManager API
- Changes from version 2.9.6:
  + Changes to the completion API to allow better language bindings
  + Add API to set a custom UndoManager on the buffer
  + Misc bugfixes
  + Updated translations
* Mon Jan 25 2010 captain.magnus@opensuse.org
- Update to version 2.9.5:
  + Misc bugfixes
  + Translation updates
* Wed Jan 13 2010 captain.magnus@opensuse.org
- Update to version 2.9.4:
  + Implement context classes and use them to mark strings,
    comments, keywords and regions where spell-check is disabled
  + More work on completion
  + Improvements to some of the lang files
  + Misc bugfixes
  + Translation updates
- sed line that removed gconf-2.0 in configure is no longer needed
* Mon Dec  7 2009 vuntz@opensuse.org
- Remove en@shaw workaround.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update to version 2.9.3:
  + Crasher bugfixes in word completion provider
  + Misc bugfixes for win32
  + Smarter autoindentation
  + New language: SPARQL
  + Misc bugfixes
  + Updated translations
- Changes from version 2.9.2:
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations
- Changes from version 2.9.1:
  + Added draw spaces for leading, text and trailing spaces
  + Merged GtkSourceCompletion branch
  + Updated translations
- Remove check for gconf-2.0 added by mistake to configure.
* Tue Sep 29 2009 vuntz@opensuse.org
- Update to version 2.8.1:
  + Misc bugfixes in gutter tooltip rendering
  + Updated translations
* Mon Sep 28 2009 vuntz@opensuse.org
- Update to version 2.8.0:
  + Misc bugfixes
  + Updated translations
* Wed Sep 16 2009 lmedinas@opensuse.org
- Update to version 2.7.5:
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations
* Tue Aug 25 2009 vuntz@novell.com
- Update to version 2.7.4:
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations
* Wed Jul 29 2009 vuntz@novell.com
- Remove unneeded update-desktop-files BuildRequires.
* Tue Jul 28 2009 lmedinas@gmail.com
- Update to version 2.7.3:
  + Misc bugfixes
* Sun Jul 19 2009 vuntz@novell.com
- Update to version 2.7.2:
  + Add GtkSourceGutter api to customize gutter drawing
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations
* Wed May 27 2009 vuntz@novell.com
- Update to version 2.7.1:
  + Add tooltips to GtkSourceMarks
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations
* Mon May 18 2009 vuntz@novell.com
- Update to version 2.6.2:
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations
* Wed Apr 15 2009 vuntz@novell.com
- Remove empty gtksourceview package and instead move the README,
  etc. files to libgtksourceview-2_0-0. This package also
  obsoletes/provides gtksourceview.
- Add gtksourceview Requires to the devel package (it should be
  libgtksourceview-2_0-0 strictly speaking, but we avoid a rpmlint
  warning this way).
* Sun Apr 12 2009 mboman@suse.de
- Update to version 2.6.1:
  + Improvements to some of the lang files
  + Translation updates
- Remove AutoReqProv. It's default
- Remove Requires libgtksourceview-2_0-0 from main package
* Sun Mar 15 2009 vuntz@novell.com
- Update to version 2.6.0:
  + Improvements to some of the lang files
  + Updated translations
- Remove BuildRequires: gnome-common, libglade2-devel.
- Add BuildRequires: gtk2-devel, libxml2-devel.
- Use --disable-gtk-doc in configure since we don't need to
  regenerate the doc.
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 2.5.6:
  + Misc bugfixes
  + Updated translations
- Add back libxml2-devel to requires of devel package to fix many
  build breaks.
- Remove -fno-strict-aliasing from CFLAGS.
- Remove AutoReqProv: it's default now.
* Sat Feb 28 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- fix -devel package dependencies, libxml2-devel not needed here.
* Tue Feb 17 2009 mboman@suse.de
- Fix Provides/Obsoletes for gtksourceview-doc.
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Sun Feb 15 2009 mboman@suse.de
- Update to version 2.5.5:
  + New "cobalt" style scheme
  + Misc bugfixes
  + Updated translations
- Move gtk-doc to -devel packages
* Thu Feb  5 2009 mboman@suse.de
- Update to version 2.5.4:
  + Improvements to some of the lang files
  + Translation updates
* Mon Feb  2 2009 mboman@suse.de
- Update to version 2.5.3:
  + Improvements to some of the lang files
  + Translation updates
* Sun Jan 25 2009 vuntz@novell.com
- Remove useless BuildRequires.
* Tue Jan  6 2009 mboman@suse.de
- Update to version 2.5.2:
  + Misc bugfixes
  + Improvements to some of the lang files
  + Translation updates
* Mon Dec 29 2008 mboman@suse.de
- Update to version 2.5.1:
  + Misc bugfixes
  + Improvements to some of the lang files
  + Translation updates
* Wed Dec 24 2008 mboman@suse.de
- Update to version 2.4.1:
  + Fix a crash when inserting images in the buffer
  + Improvements to some of the lang files
  + Translation updates
* Sun Sep 21 2008 mboman@suse.de
- Update to version 2.4.0:
  + Updated translations
* Fri Sep 12 2008 maw@suse.de
- Update to version 2.3.3:
  + Improvements to some of the lang files
  + Updated translations.
* Mon Sep  1 2008 mboman@novell.com
- Update to version 2.3.2:
  + Misc bugfixes
  + Improvements to some of the lang files
  + Updated translations
* Thu Aug 28 2008 maw@suse.de
- Update to version 2.3.1:
  + Add function to guess the language for a given filename and
    mime type; accordingly, bump the glib dependency to 2.14, which
    includes gio, and remove the gnome-vfs dep
  + Allow setting the background color of paragraphs with marks
  + Support drawing white spaces
  + Improvements to some of the lang files
  + Misc bugfixes
  + Updated translations.
* Wed Aug  6 2008 maw@suse.de
- Update to version 2.2.2:
  + Improvements to some language files
  + Misc. bugfixes
  + Updated translations.
* Wed Apr  9 2008 maw@suse.de
- Update to version 2.2.1:
  + Improve keybindings
  + Misc. bugfixes
  + Updated translations.
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.2.0:
  + Misc bugfixes
  + Updated translations.
* Tue Mar  4 2008 maw@suse.de
- Update to version 2.1.3:
  + Misc. bugfixes
  + Updated translations.
* Mon Feb 18 2008 maw@suse.de
- Update to version 2.1.2:
  + Fix a GtkSourceMark API issue
  + Updated translations.
* Fri Feb  1 2008 maw@suse.de
- Update to version 2.1.0:
  + New gtk-print based printing API
  + New GtkTextMark based GtkSourceMark API
  + Misc bugfixes
  + Updated translations.
* Mon Sep 17 2007 maw@suse.de
- Update to version 2.0.0:
  + Updated translations.
* Fri Aug 31 2007 maw@suse.de
- Update to version 2.19.4:
  + Many improvements in all the lang files
  + Minor API tweaks
  + Misc bugfixes
  + Updated translations.
* Tue Aug  7 2007 maw@suse.de
- Split off a -lang subpackage.
* Thu Aug  2 2007 maw@suse.de
- Update to version 1.90.3:
  + API breakage as of version 1.90.0
  + New highlighting and theming engine
  + GnomePrint-based print API removal
  + GtkSourceStyle is now a gobject
  + Port to GRegex
  + Support replacing contexts
  + Support symbolic colors in schemes
  + Add tango style scheme
  + Improvements for programming language description files,
    particularly those for ruby and perl
  + Updated translations
  + Misc bugfixes
- Use %%fdupes
- s#%%run_ldconfig#/sbin/ldconfig# in %%post and %%postun
- Concomitant with the API breakage, create a
  libgtksourceview-2_0-0 subpackage.
* Fri Mar 30 2007 maw@suse.de
- Update to version 1.8.5
  - updated translations
* Thu Mar  8 2007 maw@suse.de
- Update to version 1.8.4, which brings:
- RPM highlighting (Konstantin Ryabitsev)
- Fix a problem with search in accented words (Yevgen Muntyan)
- Misc lang file fixes
- Updated translations
* Wed Jan  3 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Mon Oct  2 2006 jhargadon@suse.de
- update to version 1.8.1
- Fixed #357447 – Missing break in gtk_source_tag_set_property()
- Fixed #357746 – "Insert spaces instead of tabs" doesn't work
- Updated translations
* Thu Sep 14 2006 jhargadon@suse.de
- update to version 1.8.0
- Added text/x-gettext-translation-template to the list of
  mime-types in po.lang
- Updated translations
* Tue Aug 15 2006 jhargadon@suse.de
- update to version 1.7.2
- add an 'indent-on-tab' property
- highlight fortran operators
- Updated translations
- Consume all button press events on the line numbers margin
* Wed Aug  2 2006 danw@suse.de
- intltoolize before autoreconf'ing to avoid version skew between
  configure macros and po/Makefile.in.in
* Mon Feb  6 2006 aj@suse.de
- Cleanup BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 sbrabec@suse.cz
- Updated to version 1.5.6.
* Wed Nov 30 2005 wberrier@suse.de
- Update to 1.5.1
* Thu Oct 13 2005 gekker@suse.de
- Update to version 1.4.2
* Mon Sep 26 2005 mls@suse.de
- make devel package require base package
* Tue Sep  6 2005 sbrabec@suse.cz
- Updated to version 1.4.1.
* Mon Sep  5 2005 sbrabec@suse.cz
- Updated to version 1.4.0.
* Tue Aug 23 2005 gekker@suse.de
- Update to version 1.3.92
* Thu Aug 11 2005 gekker@suse.de
- Update to version 1.3.91
* Fri Jul 22 2005 gekker@suse.de
- Update to version 1.2.1
* Tue Apr 26 2005 ke@suse.de
- The -devel subpackage requires libxml2-devel, gtk2-devel, and
  libgnomeprint-devel; reported by Ben Maurer [#80398].
* Wed Mar  9 2005 gekker@suse.de
- Update to version 1.2.0 (GNOME 2.10).
* Thu Mar  3 2005 gekker@suse.de
- Update to version 1.1.93
* Fri Feb 11 2005 gekker@suse.de
- Update to version 1.1.92
* Tue Jan 25 2005 clahey@suse.de
- Updated to version 1.1.91.
* Tue Jan 18 2005 clahey@suse.de
- Updated to version 1.1.90.
* Fri Nov 19 2004 ro@suse.de
- removed extra aclocal include directive
* Tue Nov  2 2004 ro@suse.de
- locale rename: no -> nb
* Wed May  5 2004 sbrabec@suse.cz
- Updated to version 1.0.1 (GNOME 2,6).
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Mon Oct 27 2003 sbrabec@suse.cz
- Updated to version 0.7.0.
* Fri Oct 10 2003 sbrabec@suse.cz
- Fixed docdir ownership.
* Thu Oct  9 2003 sbrabec@suse.cz
- Added new SuSE package, version 0.6.0 (GNOME 2.4).
